@@ -1,34 +1,37 @@
 #' @include get_RLum.R set_RLum.R length_RLum.R structure_RLum.R names_RLum.R smooth_RLum.R
 NULL
 
-#' Class \code{"RLum.Analysis"}
+#' Class `"RLum.Analysis"`
 #'
-#' Object class to represent analysis data for protocol analysis, i.e. all curves, spectra etc.
-#' from one measurements. Objects from this class are produced, by e.g. \code{\link{read_XSYG2R}},
-#' \code{\link{read_Daybreak2R}}
+#' Object class to represent analysis data for protocol analysis, i.e. all curves,
+#' spectra etc. from one measurements. Objects from this class are produced,
+#' by e.g. [read_XSYG2R], [read_Daybreak2R]
 #'
 #'
 #' @name RLum.Analysis-class
 #'
 #' @docType class
 #'
-#' @slot protocol Object of class \code{\link{character}} describing the applied measurement protocol
+#' @slot protocol
+#' Object of class [character] describing the applied measurement protocol
 #'
-#' @slot records Object of class \code{\link{list}} containing objects of class \code{\linkS4class{RLum.Data}}
+#' @slot records
+#' Object of class [list] containing objects of class [RLum.Data-class]
 #'
-#' @note The method \code{\link{structure_RLum}} is currently just avaiblable for objects
-#' containing \code{\linkS4class{RLum.Data.Curve}}.
+#' @note
+#' The method [structure_RLum] is currently just available for objects
+#' containing [RLum.Data.Curve-class].
 #'
-#' @section Objects from the Class: Objects can be created by calls of the form
-#' \code{set_RLum("RLum.Analysis", ...)}.
+#' @section Objects from the Class:
+#' Objects can be created by calls of the form `set_RLum("RLum.Analysis", ...)`.
 #'
-#' @section Class version: 0.4.8
+#' @section Class version: 0.4.16
 #'
-#' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
-#' (France)
+#' @author
+#' Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
 #'
-#' @seealso \code{\link{Risoe.BINfileData2RLum.Analysis}},
-#' \code{\linkS4class{Risoe.BINfileData}}, \code{\linkS4class{RLum}}
+#' @seealso [Risoe.BINfileData2RLum.Analysis],
+#' [Risoe.BINfileData-class], [RLum-class]
 #'
 #' @keywords classes methods
 #'
@@ -49,6 +52,9 @@ NULL
 #' ##show only the first object, but by keeping the object
 #' get_RLum(IRSAR.RF.Data, record.id = 1, drop = FALSE)
 #'
+#' @keywords internal
+#'
+#' @md
 #' @export
 setClass("RLum.Analysis",
          slots = list(
@@ -63,30 +69,26 @@ setClass("RLum.Analysis",
 )
 
 
-####################################################################################################
-###as()
-####################################################################################################
+# as() -----------------------------------------------------------------------------------------
 ##LIST
 ##COERCE RLum.Analyse >> list AND list >> RLum.Analysis
 #' as() - RLum-object coercion
 #'
-#' for \code{[RLum.Analysis]}
+#' for `[RLum.Analysis-class]`
 #'
-#' \bold{[RLum.Analysis]}\cr
+#' **[RLum.Analysis-class]**
 #'
 #' \tabular{ll}{
-#'  \bold{from} \tab \bold{to}\cr
-#'   \code{list} \tab \code{list}\cr
+#'  **from** \tab **to**\cr
+#'   `list` \tab `list`\cr
 #' }
 #'
-#' Given that the \code{\link{list}} consits of \code{\linkS4class{RLum.Analysis}} objects.
+#' Given that the [list] consits of [RLum.Analysis-class] objects.
 #'
+#' @md
 #' @name as
-#'
-#'
 setAs("list", "RLum.Analysis",
       function(from,to){
-
         new(to,
             protocol = NA_character_,
             records = from)
@@ -94,27 +96,26 @@ setAs("list", "RLum.Analysis",
 
 setAs("RLum.Analysis", "list",
       function(from){
-
         lapply(1:length(from@records), function(x){
           from@records[[x]]
 
         })
-
       })
 
 
-####################################################################################################
-###show()
-####################################################################################################
+# show() --------------------------------------------------------------------------------------
 #' @describeIn RLum.Analysis
-#' Show structure of \code{RLum.Analysis} object
+#' Show structure of `RLum.Analysis` object
+#'
+#' @md
 #' @export
 setMethod("show",
           signature(object = "RLum.Analysis"),
           function(object){
 
+
             ##print
-            cat("\n [RLum.Analysis]")
+            cat("\n [RLum.Analysis-class]")
 
             ##show slot originator, for compatibily reasons with old example data, here
             ##a check
@@ -138,7 +139,7 @@ setMethod("show",
               lapply(1:length(table(temp)), function(x){
 
                 ##show RLum class type
-                cat("\n\t .. :",names(table(temp)[x]),":",table(temp)[x])
+                cat("\n\t .. :", names(table(temp)[x]),":",table(temp)[x])
 
                 ##show structure
                 ##set width option ... just an implementation for the tutorial output
@@ -156,11 +157,14 @@ setMethod("show",
                         assign(x = "linebreak", value = TRUE, envir = env)
                       }
 
+
                       ##FIRST
                       first <-  paste0("#", i, " ", object@records[[i]]@recordType)
+
                       ##LAST
                       if (i < length(object@records) &&
                           !is.null(object@records[[i]]@info[["parentID"]]) &&
+                          !is.null(object@records[[i + 1]]@info[["parentID"]]) &&
                           (object@records[[i]]@info[["parentID"]] ==
                            object@records[[i+1]]@info[["parentID"]])) {
                         last <- " <> "
@@ -179,18 +183,27 @@ setMethod("show",
 
                       }
                       return(paste0(first,last))
+
+                    }else{
+                      return("")
+
                     }
 
               }, FUN.VALUE = vector(mode = "character", length = 1))
 
-                 ##print combined output
-                 cat("\n\t .. .. : ", terminal_output, sep = "")
+                 ##print on screen, differentiate between records with many curves or just one
+                 if(any(grepl(terminal_output, pattern = "<>", fixed = TRUE))){
+                   cat("\n\t .. .. : ", gsub(pattern = "|", replacement = "\n\t .. .. :", x = terminal_output, fixed = TRUE), sep = "")
+
+                 } else{
+                   cat("\n\t .. .. : ", terminal_output, sep = "")
+
+                 }
 
               })
 
             }else{
-
-              cat("\n\t >> This is an empty object and cannot be used for further analysis! <<")
+              cat("\n\t >> This is an empty object, which cannot be used for further analysis! <<")
 
             }
 
@@ -198,50 +211,55 @@ setMethod("show",
           }
 )##end show method
 
-
-####################################################################################################
-###set_RLum()
-####################################################################################################
+# set_RLum() ----------------------------------------------------------------------------------
 #' @describeIn RLum.Analysis
-#' Construction method for \code{\linkS4class{RLum.Analysis}} objects.
+#' Construction method for [RLum.Analysis-class] objects.
 #'
-#' @param class [\code{set_RLum}] \code{\link{character}} (\bold{required}): name of the \code{RLum} class to be created
-#' @param originator [\code{set_RLum}] \code{\link{character}} (automatic): contains the name
-#' of the calling function (the function that produces this object); can be set manually.
-#' @param .uid [\code{set_RLum}] \code{\link{character}} (automatic): sets an unique ID for this object
-#' using the internal C++ function \code{.create_UID}.
-#' @param .pid [\code{set_RLum}] \code{\link{character}} (with default): option to provide a parent id for nesting
-#' at will.
-#' @param protocol [\code{set_RLum}] \code{\link{character}} (optional): sets protocol type for
-#' analysis object. Value may be used by subsequent analysis functions.
-#' @param records [\code{set_RLum}] \code{\link{list}} (\bold{required}): list of \code{\linkS4class{RLum.Analysis}} objects
-#' @param info [\code{set_RLum}] \code{\link{list}} (optional): a list containing additional
-#' info data for the object
+#' @param class [`set_RLum`] [character] (**required**):
+#' name of the `RLum` class to be created
 #'
-#' \bold{\code{set_RLum}}:\cr
+#' @param originator [`set_RLum`] [character] (*automatic*):
+#' contains the name of the calling function (the function that produces this object);
+#' can be set manually.
 #'
-#' Returns an \code{\linkS4class{RLum.Analysis}} object.
+#' @param .uid [`set_RLum`] [character] (*automatic*):
+#' sets an unique ID for this object using the internal C++ function `create_UID`.
 #'
+#' @param .pid [`set_RLum`] [character] (*with default*):
+#' option to provide a parent id for nesting at will.
+#'
+#' @param protocol [`set_RLum`] [character] (*optional*):
+#' sets protocol type for analysis object. Value may be used by subsequent analysis functions.
+#'
+#' @param records [`set_RLum`] [list] (**required**):
+#' list of [RLum.Analysis-class] objects
+#'
+#' @param info [`set_RLum`] [list] (*optional*):
+#' a list containing additional info data for the object
+#'
+#' **`set_RLum`**:
+#'
+#' Returns an [RLum.Analysis-class] object.
+#'
+#' @md
 #' @export
 setMethod(
   "set_RLum",
   signature = "RLum.Analysis",
-
-  definition = function(class,
-                        originator,
-                        .uid,
-                        .pid,
-                        protocol = NA_character_,
-                        records = list(),
-                        info = list()
-                        ) {
+  definition = function(
+    class,
+    originator,
+    .uid,
+    .pid,
+    protocol = NA_character_,
+    records = list(),
+    info = list()) {
 
     ##produce empty class object
     newRLumAnalysis <- new(Class = "RLum.Analysis")
 
     ##allow self set to reset an RLum.Analysis object
-    if(is(records, "RLum.Analysis")){
-
+    if(class(records) == "RLum.Analysis"){
       #fill slots (this is much faster than the old code!)
       newRLumAnalysis@protocol <- if(missing(protocol)){records@protocol}else{protocol}
       newRLumAnalysis@originator <- originator
@@ -250,9 +268,7 @@ setMethod(
       newRLumAnalysis@.uid <- .uid
       newRLumAnalysis@.pid <- if(missing(.pid)){records@.uid}else{.pid}
 
-
     }else{
-
       #fill slots (this is much faster than the old code!)
       newRLumAnalysis@protocol <- protocol
       newRLumAnalysis@originator <- originator
@@ -268,9 +284,7 @@ setMethod(
   }
 )
 
-####################################################################################################
-###get_RLum()
-####################################################################################################
+# get_RLum() ----------------------------------------------------------------------------------
 #' @describeIn RLum.Analysis
 #' Accessor method for RLum.Analysis object.
 #'
@@ -283,62 +297,71 @@ setMethod(
 #' The selection of a specific RLum.type object superimposes the default selection.
 #' Currently supported objects are: RLum.Data.Curve and RLum.Data.Spectrum
 #'
-#' @param object \code{[show_RLum]}\code{[get_RLum]}\code{[names_RLum]}\code{[length_RLum]}
-#' \code{[structure_RLum]}] an object of class \code{\linkS4class{RLum.Analysis}}
-#' (\bold{required})
+#' @param object [`get_RLum`]: [`names_RLum`], [`length_RLum`], [`structure_RLum`] (**required**):
+#' an object of class [RLum.Analysis-class]
 #'
-#' @param record.id [\code{get_RLum}] \code{\link{numeric}} or \code{\link{logical}} (optional): IDs of specific records.
-#' If of type \code{logical} the entire id range is assuemd and \code{TRUE} and \code{FALSE} indicates the selection.
+#' @param record.id [`get_RLum`]: [numeric] or [logical] (*optional*):
+#' IDs of specific records. If of type `logical` the entire id range is assumed
+#' and `TRUE` and `FALSE` indicates the selection.
 #'
-#' @param recordType [\code{get_RLum}] \code{\link{character}} (optional): record type (e.g., "OSL").
-#' Can be also a vector, for multiple matching, e.g., \code{recordType = c("OSL", "IRSL")}
+#' @param recordType [`get_RLum`]: [character] (*optional*):
+#' record type (e.g., "OSL"). Can be also a vector, for multiple matching,
+#' e.g., `recordType = c("OSL", "IRSL")`
 #'
-#' @param curveType [\code{get_RLum}] \code{\link{character}} (optional): curve
-#' type (e.g. "predefined" or "measured")
+#' @param curveType [`get_RLum`]: [character] (*optional*):
+#' curve type (e.g. "predefined" or "measured")
 #'
-#' @param RLum.type [\code{get_RLum}] \code{\link{character}} (optional): RLum object type.
-#' Defaults to "RLum.Data.Curve" and "RLum.Data.Spectrum".
+#' @param RLum.type [`get_RLum`]: [character] (*optional*):
+#' RLum object type. Defaults to "RLum.Data.Curve" and "RLum.Data.Spectrum".
 #'
-#' @param get.index [\code{get_RLum}] \code{\link{logical}} (optional): return a numeric
-#' vector with the index of each element in the RLum.Analysis object.
+#' @param get.index [`get_RLum`]: [logical] (*optional*):
+#' return a numeric vector with the index of each element in the RLum.Analysis object.
 #'
-#' @param recursive [\code{get_RLum}] \code{\link{logical}} (with default): if \code{TRUE} (the default)
-#' and the result of the 'get_RLum' request is a single object this object will be unlisted, means
-#' only the object itself and no list containing exactly one object is returned. Mostly this makes things
-#' easier, however, if this method is used within a loop this might undesired.
+#' @param recursive [`get_RLum`]: [logical] (*with default*):
+#' if `TRUE` (the default) and the result of the 'get_RLum' request is a single
+#' object this object will be unlisted, means only the object itself and no
+#' list containing exactly one object is returned. Mostly this makes things
+#' easier, however, if this method is used within a loop this might be undesired.
 #'
-#' @param drop [\code{get_RLum}] \code{\link{logical}} (with default): coerce to the next possible layer
-#' (which are \code{RLum.Data}-objects), \code{drop = FALSE} keeps the original \code{RLum.Analysis}
+#' @param drop [`get_RLum`]: [logical] (*with default*):
+#' coerce to the next possible layer (which are `RLum.Data`-objects),
+#' `drop = FALSE` keeps the original `RLum.Analysis`
 #'
-#' @param info.object [\code{get_RLum}] \code{\link{character}} (optional): name of the wanted info
-#' element
+#' @param info.object [`get_RLum`]: [character] (*optional*):
+#' name of the wanted info element
 #'
-#' @param subset \code{\link{expression}} (optional): logical expression indicating elements or rows
-#' to keep: missing values are taken as false. This argument takes precedence over all
-#' other arguments, meaning they are not considered when subsetting the object.
+#' @param subset [`get_RLum`]: [expression] (*optional*):
+#' logical expression indicating elements or rows to keep: missing values are
+#' taken as false. This argument takes precedence over all other arguments,
+#' meaning they are not considered when subsetting the object.
+#'
+#' @param env [`get_RLum`]: [environment] (*with default*):
+#' An environment passed to [eval] as the enclosure. This argument is only
+#' relevant when subsetting the object and should not be used manually.
 #'
 #' @return
 #'
-#' \bold{\code{get_RLum}}:\cr
+#' **`get_RLum`**:
 #'
-#' Returns: \cr
-#' (1) \code{\link{list}} of \code{\linkS4class{RLum.Data}} objects or \cr
-#' (2) Single \code{\linkS4class{RLum.Data}} object, if only one object is contained and
-#' \code{recursive = FALSE} or\cr
-#' (3) \code{\linkS4class{RLum.Analysis}} ojects for \code{drop = FALSE} \cr
+#' Returns:
 #'
+#' 1. [list] of [RLum.Data-class] objects or
+#' 2. Single [RLum.Data-class] object, if only one object is contained and `recursive = FALSE` or
+#' 3. [RLum.Analysis-class] ojects for `drop = FALSE`
+#'
+#' @md
 #' @export
 setMethod("get_RLum",
           signature = ("RLum.Analysis"),
 
           function(object, record.id = NULL, recordType = NULL, curveType = NULL, RLum.type = NULL,
-                   protocol = "UNKNOWN", get.index = NULL, drop = TRUE, recursive = TRUE, info.object = NULL, subset = NULL) {
+                   protocol = "UNKNOWN", get.index = NULL, drop = TRUE, recursive = TRUE, info.object = NULL, subset = NULL, env = parent.frame(2)) {
 
             if (!is.null(substitute(subset))) {
 
               # To account for different lengths and elements in the @info slot we first
-              # check all unique elements
-              info_el <- unique(unlist(sapply(object@records, function(el) names(el@info))))
+              # check all unique elements (in all records)
+              info_el <- unique(unlist(lapply(object@records, function(el) names(el@info))))
 
               envir <- as.data.frame(do.call(rbind,
                                              lapply(object@records, function(el) {
@@ -348,22 +371,27 @@ setMethod("get_RLum",
                                                if (any(!info_el %in% names(val))) {
                                                  val_new <- setNames(rep(NA, length(info_el[!info_el %in% names(val)])), info_el[!info_el %in% names(val)])
                                                  val <- c(val, val_new)
+
                                                }
 
-                                               # order the named char vector by its names so we dont mix up the columns
+                                               # order the named char vector by its names so we don't mix up the columns
                                                val <- val[order(names(val))]
                                                return(val)
-                                               })
-                                             ))
+                                             })
+              ), stringsAsFactors = FALSE)
+
+              ##check for a logical expression, to avoid problems afterwards
+              # if(class(eval(substitute(subset), envir = envir, enclos = env)) != "logical")
+              #   stop("[get_RLum] The argument 'subset' does not contain a logical expression!", call. = FALSE)
 
               ##select relevant rows
               sel <- tryCatch(eval(
                 expr = substitute(subset),
                 envir = envir,
-                enclos = parent.frame()
+                enclos = env
               ),
               error = function(e) {
-                stop("\n\n [ERROR] Invalid subset options. \nValid terms are: ", paste(names(envir), collapse = ", "))
+                stop("[get_RLum()] Invalid subset options. \nValid terms are: ", paste(names(envir), collapse = ", "), call. = FALSE)
               })
 
               if (all(is.na(sel)))
@@ -374,7 +402,7 @@ setMethod("get_RLum",
                 return(object)
               } else {
                 tmp <- mapply(function(name, op) { message("  ",name, ": ", paste(unique(op),  collapse = ", ")) }, names(envir), envir)
-                message("\n [ERROR] Invalid value, please refer to unique options given above.")
+                message("\n [get_RLum()] Invalid value, please refer to unique options given above.")
                 return(NULL)
               }
 
@@ -382,40 +410,33 @@ setMethod("get_RLum",
 
             ##if info.object is set, only the info objects are returned
             else if(!is.null(info.object)) {
-
               if(info.object %in% names(object@info)){
-
                 unlist(object@info[info.object])
 
               }else{
-
                 ##check for entries
                 if(length(object@info) == 0){
-
-                  warning("[get_RLum] This RLum.Analysis object has no info objects! NULL returned!)")
-                  return(NULL)
+                  warning(
+                    "[get_RLum()] This RLum.Analysis object has no info objects! NULL returned!)",
+                          call. = FALSE)
 
                 }else{
-
-                  ##grep names
-                  temp.element.names <- paste(names(object@info), collapse = ", ")
-
-                  warning.text <- paste("[get_RLum] Invalid info.object name. Valid names are:", temp.element.names)
-
-                  warning(warning.text, call. = FALSE)
-                  return(NULL)
+                  warning(paste0(
+                    "[get_RLum()] Invalid info.object name. Valid names are: ",
+                    paste(names(object@info), collapse = ", ")
+                  ),
+                  call. = FALSE)
 
                 }
-
+                return(NULL)
               }
 
-
             } else {
 
               ##check for records
               if (length(object@records) == 0) {
 
-                warning("[get_RLum] This RLum.Analysis object has no records! NULL returned!)")
+                warning("[get_RLum()] This RLum.Analysis object has no records! NULL returned!)")
                 return(NULL)
 
               }
@@ -424,15 +445,15 @@ setMethod("get_RLum",
               if (is.null(record.id)) {
                 record.id <- c(1:length(object@records))
 
-              } else if (!is(record.id, "numeric") &
-                         !is(record.id, "logical")) {
-                stop("[get_RLum()] 'record.id' has to be of type 'numeric' or 'logical'!")
+              } else if (!is.numeric(record.id) &
+                         !is.logical(record.id)) {
+                stop("[get_RLum()] 'record.id' has to be of type 'numeric' or 'logical'!", call. = FALSE)
 
               }
               ##logical needs a slightly different treatment
               ##Why do we need this? Because a lot of standard R functions work with logical
               ##values instead of numerical indicies
-              if (is(record.id, "logical")) {
+              if (is.logical(record.id)) {
                 record.id <- c(1:length(object@records))[record.id]
 
               }
@@ -451,11 +472,8 @@ setMethod("get_RLum",
                                                      object@records[[x]]@recordType
                                                    })))
 
-              } else{
-                if (!is(recordType, "character")) {
-                  stop("[get_RLum()] 'recordType' has to be of type 'character'!")
-
-                }
+              } else if (class(recordType) != "character"){
+                  stop("[get_RLum()] 'recordType' has to be of type 'character'!", call. = FALSE)
 
               }
 
@@ -467,16 +485,16 @@ setMethod("get_RLum",
                                                   })))
 
               } else if (!is(curveType, "character")) {
-                stop("[get_RLum()] 'curveType' has to be of type 'character'!")
+                stop("[get_RLum()] 'curveType' has to be of type 'character'!", call. = FALSE)
 
               }
 
               ##RLum.type
               if (is.null(RLum.type)) {
-                RLum.type <- c("RLum.Data.Curve", "RLum.Data.Spectrum")
+                RLum.type <- c("RLum.Data.Curve", "RLum.Data.Spectrum", "RLum.Data.Image")
 
               } else if (!is(RLum.type, "character")) {
-                stop("[get_RLum()] 'RLum.type' has to be of type 'character'!")
+                stop("[get_RLum()] 'RLum.type' has to be of type 'character'!", call. = FALSE)
 
               }
 
@@ -485,7 +503,7 @@ setMethod("get_RLum",
                 get.index <- FALSE
 
               } else if (!is(get.index, "logical")) {
-                stop("[get_RLum()] 'get.index' has to be of type 'logical'!")
+                stop("[get_RLum()] 'get.index' has to be of type 'logical'!", call. = FALSE)
 
               }
 
@@ -614,33 +632,32 @@ setMethod("get_RLum",
           })
 
 
-####################################################################################################
-###structure_RLum()
-####################################################################################################
+# structure_RLum() ----------------------------------------------------------------------------
+###
 #' @describeIn RLum.Analysis
-#' Method to show the structure of an \code{\linkS4class{RLum.Analysis}} object.
+#' Method to show the structure of an [RLum.Analysis-class] object.
 #'
-#' @param fullExtent [structure_RLum] \code{\link{logical}} (with default): extents the returned \code{data.frame}
-#' to its full extent, i.e. all info elements are part of the return as well. The default valule
-#' is \code{FALSE} as the data frame might become rather big.
+#' @param fullExtent [structure_RLum]; [logical] (*with default*):
+#' extents the returned `data.frame` to its full extent, i.e. all info elements
+#' are part of the return as well. The default value is `FALSE` as the data
+#' frame might become rather big.
 #'
 #' @return
 #'
-#' \bold{\code{structure_RLum}}:\cr
+#' **`structure_RLum`**:
 #'
-#' Returns \code{\linkS4class{data.frame}} showing the structure.
+#' Returns [data.frame-class] showing the structure.
 #'
+#' @md
 #' @export
 setMethod("structure_RLum",
           signature= "RLum.Analysis",
           definition = function(object, fullExtent = FALSE) {
 
             ##check if the object containing other elements than allowed
-            if(length(grep(FALSE, sapply(object@records, is, class="RLum.Data.Curve")))!=0){
-
-              stop("[structure_RLum()]  Only 'RLum.Data.Curve' objects are allowed!" )
-
-            }
+            if(!all(vapply(object@records, FUN = class, character(1)) == "RLum.Data.Curve"))
+              stop("[structure_RLum()]  Only 'RLum.Data.Curve' objects are allowed!",
+                   call. = FALSE)
 
             ##get length object
             temp.object.length <- length(object@records)
@@ -648,41 +665,37 @@ setMethod("structure_RLum",
             ##ID
             temp.id <- 1:temp.object.length
 
-            ##OBJECT TYPE
-            temp.recordType <- c(NA)
-            length(temp.recordType) <- temp.object.length
-            temp.recordType <- sapply(1:temp.object.length,
-                                      function(x){object@records[[x]]@recordType})
+            ##recordType
+            temp.recordType <-
+              vapply(object@records, function(x) {
+                x@recordType
+              }, character(1))
 
             ##PROTOCOL STEP
             temp.protocol.step <- c(NA)
             length(temp.protocol.step) <- temp.object.length
 
             ##n.channels
-            temp.n.channels <- sapply(1:temp.object.length,
-                                      function(x){length(object@records[[x]]@data[,1])})
+            temp.n.channels <- vapply(object@records, function(x){length(x@data[,1])}, numeric(1))
 
             ##X.MIN
-            temp.x.min <- sapply(1:temp.object.length,
-                                 function(x){min(object@records[[x]]@data[,1])})
+            temp.x.min <- vapply(object@records, function(x){min(x@data[,1])}, numeric(1))
 
             ##X.MAX
-            temp.x.max <- sapply(1:temp.object.length,
-                                 function(x){max(object@records[[x]]@data[,1])})
+            temp.x.max <- vapply(object@records, function(x){max(x@data[,1])}, numeric(1))
 
             ##y.MIN
-            temp.y.min <- sapply(1:temp.object.length,
-                                 function(x){min(object@records[[x]]@data[,2])})
+            temp.y.min <- vapply(object@records, function(x){min(x@data[,2])}, numeric(1))
 
             ##X.MAX
-            temp.y.max <- sapply(1:temp.object.length,
-                                 function(x){max(object@records[[x]]@data[,2])})
+            temp.y.max <- vapply(object@records, function(x){max(x@data[,2])}, numeric(1))
 
             ##.uid
             temp.uid <- unlist(lapply(object@records, function(x){x@.uid}))
 
             ##.pid
-            temp.pid <- unlist(lapply(object@records, function(x){x@.pid}))
+            temp.pid <- paste(
+              unlist(lapply(object@records, function(x){x@.pid})), collapse = ", ")
 
             ##originator
             temp.originator <- unlist(lapply(object@records, function(x){x@originator}))
@@ -732,18 +745,17 @@ setMethod("structure_RLum",
           })
 
 
-####################################################################################################
-###length_RLum()
-####################################################################################################
+# length_RLum() -------------------------------------------------------------------------------
 #' @describeIn RLum.Analysis
 #' Returns the length of the object, i.e., number of stored records.
 #'
 #' @return
 #'
-#' \bold{\code{length_RLum}}\cr
+#' **`length_RLum`**
 #'
 #' Returns the number records in this object.
 #'
+#' @md
 #' @export
 setMethod("length_RLum",
           "RLum.Analysis",
@@ -752,18 +764,17 @@ setMethod("length_RLum",
 
           })
 
-####################################################################################################
-###names_RLum()
-####################################################################################################
+# names_RLum() --------------------------------------------------------------------------------
 #' @describeIn RLum.Analysis
-#' Returns the names of the \code{\linkS4class{RLum.Data}} objects objects (same as shown with the show method)
+#' Returns the names of the [RLum.Data-class] objects objects (same as shown with the show method)
 #'
 #' @return
 #'
-#' \bold{\code{names_RLum}}\cr
+#' **`names_RLum`**
 #'
-#' Returns the names of the record types (recordType) in this object.
+#' Returns the names of the record types (`recordType`) in this object.
 #'
+#' @md
 #' @export
 setMethod("names_RLum",
           "RLum.Analysis",
@@ -774,29 +785,27 @@ setMethod("names_RLum",
           })
 
 
-####################################################################################################
-###smooth_RLum()
-####################################################################################################
+# smooth_RLum() -------------------------------------------------------------------------------
 #' @describeIn RLum.Analysis
 #'
-#' Smoothing of \code{RLum.Data} objects contained in this \code{RLum.Analysis} object
-#' \code{\link[zoo]{rollmean}} or \code{\link[zoo]{rollmedian}}.
-#' In particular the internal function \code{.smoothing} is used.
+#' Smoothing of `RLum.Data` objects contained in this `RLum.Analysis` object
+#' [zoo::rollmean] or [zoo::rollmedian][zoo::rollmean]. In particular the internal
+#' function `.smoothing` is used.
 #'
 #' @param ... further arguments passed to underlying methods
 #'
 #' @return
 #'
-#' \bold{\code{smooth_RLum}}\cr
+#' **`smooth_RLum`**
 #'
 #' Same object as input, after smoothing
 #'
+#' @md
 #' @export
 setMethod(
   f = "smooth_RLum",
   signature = "RLum.Analysis",
   function(object, ...) {
-
         object@records <- lapply(object@records, function(x){
           smooth_RLum(x, ...)
 
