@@ -8,76 +8,92 @@
 #' and a known laboratory dose administered which is treated as unknown. Then
 #' the De measurement is carried out and the degree of congruence between
 #' administered and recovered dose is a measure of the protocol's accuracy for
-#' this sample.\cr In the plot the normalised De is shown on the y-axis, i.e.
-#' obtained De/Given Dose.
+#' this sample.\cr
+#' In the plot the normalised De is shown on the y-axis, i.e. obtained De/Given Dose.
 #'
-#' @param values \code{\linkS4class{RLum.Results}} or \code{\link{data.frame}},
-#' (\bold{required}): input values containing at least De and De error. To plot
-#' more than one data set in one figure, a \code{list} of the individual data
-#' sets must be provided (e.g. \code{list(dataset.1, dataset.2)}).
+#' @param values [RLum.Results-class] or [data.frame] (**required**):
+#' input values containing at least De and De error. To plot
+#' more than one data set in one figure, a `list` of the individual data
+#' sets must be provided (e.g. `list(dataset.1, dataset.2)`).
 #'
-#' @param given.dose \code{\link{numeric}} (optional): given dose used for the
-#' dose recovery test to normalise data. If only one given dose is provided
-#' this given dose is valid for all input data sets (i.e., \code{values} is a
-#' list).  Otherwise a given dose for each input data set has to be provided
-#' (e.g., \code{given.dose = c(100,200)}). If no \code{given.dose} values are
-#' plotted without normalisation (might be useful for preheat plateau tests).
-#' Note: Unit has to be the same as from the input values (e.g., Seconds or
+#' @param given.dose [numeric] (*optional*):
+#' given dose used for the dose recovery test to normalise data.
+#' If only one given dose is provided this given dose is valid for all input
+#' data sets (i.e., `values` is a list).  Oherwise a given dose for each input
+#' data set has to be provided (e.g., `given.dose = c(100,200)`).
+#' If `given.dose` in `NULL` the values are plotted without normalisation
+#' (might be useful for preheat plateau tests).
+#' **Note:** Unit has to be the same as from the input values (e.g., Seconds or
 #' Gray).
 #'
-#' @param error.range \code{\link{numeric}}: symmetric error range in percent
-#' will be shown as dashed lines in the plot. Set \code{error.range} to 0 to
-#' void plotting of error ranges.
+#' @param error.range [numeric]:
+#' symmetric error range in percent will be shown as dashed lines in the plot.
+#' Set `error.range` to 0 to void plotting of error ranges.
 #'
-#' @param preheat \code{\link{numeric}}: optional vector of preheat
-#' temperatures to be used for grouping the De values. If specified, the
-#' temperatures are assigned to the x-axis.
+#' @param preheat [numeric]:
+#' optional vector of preheat temperatures to be used for grouping the De values.
+#' If specified, the temperatures are assigned to the x-axis.
 #'
-#' @param boxplot \code{\link{logical}}: optionally plot values, that are
-#' grouped by preheat temperature as boxplots. Only possible when
-#' \code{preheat} vector is specified.
+#' @param boxplot [logical]:
+#' optionally plot values, that are grouped by preheat temperature as boxplots.
+#'  Only possible when `preheat` vector is specified.
 #'
-#' @param mtext \code{\link{character}}: additional text below the plot title.
+#' @param mtext [character]:
+#' additional text below the plot title.
 #'
-#' @param summary \code{\link{character}} (optional): adds numerical output to
-#' the plot.  Can be one or more out of: \code{"n"} (number of samples),
-#' \code{"mean"} (mean De value), \code{"mean.weighted"} (error-weighted mean),
-#' \code{"median"} (median of the De values), \code{"sdrel"} (relative standard
-#' deviation in percent), \code{"sdabs"} (absolute standard deviation),
-#' \code{"serel"} (relative standard error) and \code{"seabs"} (absolute
-#' standard error).
+#' @param summary [character] (*optional*):
+#' adds numerical output to the plot.  Can be one or more out of:
+#' - `"n"` (number of samples),
+#' - `"mean"` (mean De value),
+#' - `"weighted$mean"` (error-weighted mean),
+#' - `"median"` (median of the De values),
+#' - `"sd.rel"` (relative standard deviation in percent),
+#' - `"sd.abs"` (absolute standard deviation),
+#' - `"se.rel"` (relative standard error) and
+#' - `"se.abs"` (absolute standard error)
 #'
-#' @param summary.pos \code{\link{numeric}} or \code{\link{character}} (with
-#' default): optional position coordinates or keyword (e.g. \code{"topright"})
-#' for the statistical summary. Alternatively, the keyword \code{"sub"} may be
+#' and all other measures returned by the function [calc_Statistics].
+#'
+#' @param summary.pos [numeric] or [character] (*with default*):
+#' optional position coordinates or keyword (e.g. `"topright"`)
+#' for the statistical summary. Alternatively, the keyword `"sub"` may be
 #' specified to place the summary below the plot header. However, this latter
-#' option in only possible if \code{mtext} is not used.
+#' option in only possible if `mtext` is not used.
 #'
-#' @param legend \code{\link{character}} vector (optional): legend content to
-#' be added to the plot.
+#' @param legend [character] vector (*optional*):
+#' legend content to be added to the plot.
 #'
-#' @param legend.pos \code{\link{numeric}} or \code{\link{character}} (with
-#' default): optional position coordinates or keyword (e.g. \code{"topright"})
-#' for the legend to be plotted.
-#' @param par.local \code{\link{logical}} (with default): use local graphical
-#' parameters for plotting, e.g. the plot is shown in one column and one row.
-#' If \code{par.local = FALSE}, global parameters are inherited.
-#' @param na.rm \code{\link{logical}}: indicating wether \code{NA} values are
+#' @param legend.pos [numeric] or [character] (*with default*):
+#' optional position coordinates or keyword (e.g. `"topright"`) for the
+#' legend to be plotted.
+#'
+#' @param par.local [logical] (*with default*):
+#' use local graphical parameters for plotting, e.g. the plot is shown in one
+#' column and one row. If `par.local = FALSE`, global parameters are inherited,
+#' i.e. parameters provided via `par()` work
+#'
+#' @param na.rm [logical]: indicating whether `NA` values are
 #' removed before plotting from the input data set
-#' @param \dots further arguments and graphical parameters passed to
-#' \code{\link{plot}}.
+#'
+#' @param ... further arguments and graphical parameters passed to [plot], supported are:
+#' `xlab`, `ylab`, `xlim`, `ylim`, `main`, `cex`, `las` and `pch``
+#'
 #' @return A plot is returned.
 #'
-#' @note Further data and plot arguments can be added by using the appropiate R
+#' @note
+#' Further data and plot arguments can be added by using the appropriate R
 #' commands.
-#' @section Function version: 0.1.10
 #'
-#' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
-#' (France), Michael Dietze, GFZ Potsdam (Germany)
+#' @section Function version: 0.1.13
 #'
-#' @seealso \code{\link{plot}}
+#' @author
+#' Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060 - Université Bordeaux Montaigne (France)\cr
+#' Michael Dietze, GFZ Potsdam (Germany)
 #'
-#' @references Wintle, A.G., Murray, A.S., 2006. A review of quartz optically
+#' @seealso [plot]
+#'
+#' @references
+#' Wintle, A.G., Murray, A.S., 2006. A review of quartz optically
 #' stimulated luminescence characteristics and their relevance in
 #' single-aliquot regeneration dating protocols. Radiation Measurements, 41,
 #' 369-391.
@@ -86,7 +102,6 @@
 #'
 #' @examples
 #'
-#'
 #' ## read example data set and misapply them for this plot type
 #' data(ExampleData.DeValues, envir = environment())
 #'
@@ -147,6 +162,7 @@
 #'                 preheat = c(200, 200, 200, 240, 240),
 #'                 boxplot = TRUE)
 #'
+#' @md
 #' @export
 plot_DRTResults <- function(
   values,
@@ -258,6 +274,9 @@ plot_DRTResults <- function(
     abs(seq(from = 20, to = -100))
   }
 
+  ##axis labels
+  las <- if("las" %in% names(extraArgs)) extraArgs$las else 0
+
   fun <- if("fun" %in% names(extraArgs)) {extraArgs$fun} else {FALSE}
 
   ## calculations and settings-------------------------------------------------
@@ -268,8 +287,7 @@ plot_DRTResults <- function(
     if(length(given.dose) > 1){
 
       if(length(values) < length(given.dose)){
-
-        stop("[plot_DRTResults()] 'given.dose' > number of input data sets!")
+        stop("[plot_DRTResults()] 'given.dose' > number of input data sets!", call. = FALSE)
 
       }
 
@@ -327,108 +345,33 @@ plot_DRTResults <- function(
     } else {
       rep(seq(from = 1, to = length(values)), length(modes))
     }
-
   }
 
   ## calculate and paste statistical summary
-  label.text = list(NA)
-
   if(summary.pos[1] != "sub") {
-    n.rows <- length(summary)
+    label.text <- lapply(1:length(values), function(i) {
+      .create_StatisticalSummaryText(
+        x = calc_Statistics(values[[i]]),
+        keywords = summary,
+        digits = 2,
+        sep = " \n",
+        prefix = paste(rep("\n", (i - 1) * length(summary)), collapse = "")
+      )
+    })
+
+  }else{
+    label.text <- lapply(1:length(values), function(i) {
+      .create_StatisticalSummaryText(
+        x = calc_Statistics(values[[i]]),
+        keywords = summary,
+        digits = 2,
+        sep = " | "
+      )
+    })
 
-    for(i in 1:length(values)) {
-      stops <- paste(rep("\n", (i - 1) * n.rows), collapse = "")
-      label.text[[length(label.text) + 1]] <- paste(stops, paste(
-        ifelse("n" %in% summary == TRUE,
-               paste("n = ",
-                     nrow(values[[i]]),
-                     "\n",
-                     sep = ""),
-               ""),
-        ifelse("mean" %in% summary == TRUE,
-               paste("mean = ",
-                     round(mean(values[[i]][,1]), 2),
-                     "\n",
-                     sep = ""),
-               ""),
-        ifelse("mean.weighted" %in% summary == TRUE,
-               paste("weighted mean = ",
-                     round(weighted.mean(x = values[[i]][,1],
-                                         w = 1 / values[[i]][,2]), 2),
-                     "\n",
-                     sep = ""),
-               ""),
-        ifelse("median" %in% summary == TRUE,
-               paste("median = ",
-                     round(median(values[[i]][,1]), 2),
-                     "\n",
-                     sep = ""),
-               ""),
-        ifelse("sdrel" %in% summary == TRUE,
-               paste("sd = ",
-                     round(sd(values[[i]][,1]) / mean(values[[i]][,1]) * 100,
-                           2), " %",
-                     "\n",
-                     sep = ""),
-               ""),
-        ifelse("sdabs" %in% summary == TRUE,
-               paste("sd = ",
-                     round(sd(values[[i]][,1]), 2),
-                     "\n",
-                     sep = ""),
-               ""),
-        sep = ""), stops, sep = "")
 
-    }
-  } else {
-    for(i in 1:length(values)) {
-      label.text[[length(label.text) + 1]]  <- paste(
-        "| ",
-        ifelse("n" %in% summary == TRUE,
-               paste("n = ",
-                     nrow(values[[i]]),
-                     " | ",
-                     sep = ""),
-               ""),
-        ifelse("mean" %in% summary == TRUE,
-               paste("mean = ",
-                     round(mean(values[[i]][,1]), 2),
-                     " | ",
-                     sep = ""),
-               ""),
-        ifelse("mean.weighted" %in% summary == TRUE,
-               paste("weighted mean = ",
-                     round(weighted.mean(x = values[[i]][,1],
-                                         w = 1 / values[[i]][,2]), 2),
-                     " | ",
-                     sep = ""),
-               ""),
-        ifelse("median" %in% summary == TRUE,
-               paste("median = ",
-                     round(median(values[[i]][,1]), 2),
-                     " | ",
-                     sep = ""),
-               ""),
-        ifelse("sdrel" %in% summary == TRUE,
-               paste("sd = ",
-                     round(sd(values[[i]][,1]) / mean(values[[i]][,1]) * 100,
-                           2), " %",
-                     " | ",
-                     sep = ""),
-               ""),
-        ifelse("sdabs" %in% summary == TRUE,
-               paste("sd = ",
-                     round(sd(values[[i]][,1]), 2),
-                     " | ",
-                     sep = ""),
-               ""),
-        sep = "")
-    }
   }
 
-  ## remove dummy list element
-  label.text[[1]] <- NULL
-
   ## convert keywords into summary placement coordinates
   if(missing(summary.pos) == TRUE) {
     summary.pos <- c(xlim[1], ylim[2])
@@ -511,6 +454,8 @@ plot_DRTResults <- function(
   ## setup plot area
   if(par.local){
 
+    if (shift.lines <= 0)
+      shift.lines <- 1
     par.default <- par()[c("mfrow", "cex", "oma")]
     par(mfrow = c(1, 1), cex = cex, oma = c(0, 1, shift.lines - 1, 1))
   }
@@ -526,10 +471,12 @@ plot_DRTResults <- function(
            xlab = xlab,
            ylab = ylab,
            xaxt = "n",
-           main = "")
+           las = las,
+           main = ""
+           )
 
       ##add x-axis ... this avoids digits in the axis labeling
-      axis(side = 1, at = 1:(nrow(values[[1]])+1), labels = 1:(nrow(values[[1]])+1))
+      axis(side = 1, at = 1:(nrow(values[[1]])+1), labels = 1:(nrow(values[[1]])+1), las = las)
 
       ## add title
       title(main = main,
@@ -565,10 +512,11 @@ plot_DRTResults <- function(
 
       ## add data and error bars
       for(i in 1:length(values)) {
+
         points(x = c(1:nrow(values[[i]])),
                y = values[[i]][,1],
-               pch = pch[i],
-               col = col[i],
+               pch = if(nrow(values[[i]]) == length(pch)){ pch } else { pch[i] },
+               col = if(nrow(values[[i]]) == length(col)){ col } else { col[i] },
                cex = 1.2 * cex)
 
         arrows(c(1:nrow(values[[i]])),
@@ -578,7 +526,7 @@ plot_DRTResults <- function(
                angle = 90,
                length = 0.075,
                code = 3,
-               col = col[i])
+               col = if(nrow(values[[i]]) == length(col)){ col } else { col[i] })
 
         ## add summary content
         if(summary.pos[1] != "sub") {
@@ -587,13 +535,13 @@ plot_DRTResults <- function(
                adj = summary.adj,
                labels = label.text[[i]],
                cex = 0.8 * cex,
-               col = col[i])
+               col = if(nrow(values[[i]]) == length(col)){ "black" } else { col[i] })
         } else {
           if(mtext == "") {
             mtext(side = 3,
                   line = - i + 2.5,
                   text = label.text[[i]],
-                  col = col[i],
+                  col = if(nrow(values[[i]]) == length(col)){ "black" } else { col[i] },
                   cex = cex * 0.8)
           }
         }
@@ -607,6 +555,7 @@ plot_DRTResults <- function(
            ylim = ylim,
            xlab = xlab,
            ylab = ylab,
+           las = las,
            main = "",
            axes = FALSE,
            frame.plot = TRUE)
@@ -676,13 +625,14 @@ plot_DRTResults <- function(
             ylim = ylim,
             xlab = xlab,
             ylab = ylab,
+            las = las,
             xaxt = "n",
             main = "",
             border = col)
 
     ## add axis label, if necessary
     if (length(modes.plot) == 1) {
-      axis(side = 1, at = 1, labels = modes.plot)
+      axis(side = 1, at = 1, labels = modes.plot, las = las)
 
     } else if (length(modes.plot) > length(unique(modes.plot))){
 
@@ -693,6 +643,7 @@ plot_DRTResults <- function(
       axis(
         side = 1,
         at = ticks,
+        las = las,
         labels = unique(modes.plot)
       )
 
@@ -721,8 +672,7 @@ plot_DRTResults <- function(
       }
 
     }else{
-
-      axis(side = 1, at = 1:length(unique(modes.plot)), labels = unique(modes.plot))
+      axis(side = 1, at = 1:length(unique(modes.plot)), labels = unique(modes.plot), las = las)
 
     }
 
@@ -731,18 +681,20 @@ plot_DRTResults <- function(
           line = shift.lines + 2)
 
     ## add additional lines
-    abline(h = 1)
+    if(!is.null(given.dose)){
+      abline(h = 1)
 
-    if(error.range > 0){
-      ## error range lines
-      abline(h = 1 * (1 + error.range / 100), lty = 2)
-      abline(h = 1 * (1 - error.range / 100), lty = 2)
+      if(error.range > 0){
+        ## error range lines
+        abline(h = 1 * (1 + error.range / 100), lty = 2)
+        abline(h = 1 * (1 - error.range / 100), lty = 2)
 
-      ## error range labels
-      text(par()$usr[2], (1 + error.range / 100) + 0.02,
-           paste("+", error.range ," %", sep = ""), pos = 2, cex = 0.8)
-      text(par()$usr[2], (1 - error.range / 100) - 0.02,
-           paste("-", error.range ,"%", sep = ""), pos = 2, cex = 0.8)
+        ## error range labels
+        text(par()$usr[2], (1 + error.range / 100) + 0.02,
+             paste("+", error.range ," %", sep = ""), pos = 2, cex = 0.8)
+        text(par()$usr[2], (1 - error.range / 100) - 0.02,
+             paste("-", error.range ,"%", sep = ""), pos = 2, cex = 0.8)
+      }
     }
 
     ## plot data and error
@@ -754,13 +706,13 @@ plot_DRTResults <- function(
              adj = summary.adj,
              labels = label.text[[i]],
              cex = 0.8 * cex,
-             col = col[i])
+             col = if(nrow(values[[i]]) == length(col)){ "black" } else { col[i] })
       } else {
         if(mtext == "") {
           mtext(side = 3,
                 line = - i + 2.5,
                 text = label.text[[i]],
-                col = col[i],
+                col = if(nrow(values[[i]]) == length(col)){ "black" } else { col[i] },
                 cex = cex * 0.8)
         }
       }
@@ -774,8 +726,8 @@ plot_DRTResults <- function(
            xjust = legend.adj[1],
            yjust = legend.adj[2],
            legend = legend,
-           col = col,
-           pch = pch,
+           col = unique(col),
+           pch = unique(pch),
            lty = 1,
            cex = cex * 0.8)
   }
@@ -796,3 +748,4 @@ plot_DRTResults <- function(
   if(fun == TRUE) {sTeve()}
 
 }
+
