@@ -1,6 +1,6 @@
 #' Import XSYG files to R
 #'
-#' Imports XSYG files produced by a Freiberg Instrument lexsyg reader into R.
+#' Imports XSYG-files produced by a Freiberg Instruments lexsyg reader into R.
 #'
 #' **How does the import function work?**
 #'
@@ -61,7 +61,7 @@
 #' **Note:**
 #' Please note that due to the recalculation of the temperature
 #' values based on values delivered by the heating element, it may happen that
-#' mutiple count values exists for each temperature value and temperature
+#' multiple count values exists for each temperature value and temperature
 #' values may also decrease during heating, not only increase.
 #'
 #' **Advanced file import**
@@ -75,9 +75,9 @@
 #'
 #' @param file [character] or [list] (**required**):
 #' path and file name of the XSYG file. If input is a `list` it should comprise
-#' only `character`s representing each valid path and xsyg-file names.
+#' only `character`s representing each valid path and XSYG-file names.
 #' Alternatively the input character can be just a directory (path), in this case the
-#' the function tries to detect and import all xsyg files found in the directory.
+#' the function tries to detect and import all XSYG-files found in the directory.
 #'
 #' @param recalculate.TL.curves [logical] (*with default*):
 #' if set to `TRUE`, TL curves are returned as temperature against count values
@@ -125,11 +125,11 @@
 #' Corresponding values in the XSXG file are skipped.
 #'
 #'
-#' @section Function version: 0.6.6
+#' @section Function version: 0.6.8
 #'
 #'
 #' @author
-#' Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne (France)
+#' Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
 #'
 #'
 #' @seealso [xml], [RLum.Analysis-class], [RLum.Data.Curve-class], [approx]
@@ -141,7 +141,7 @@
 #'
 #' **Further reading**
 #'
-#' XML: [http://en.wikipedia.org/wiki/XML]()
+#' XML: [https://en.wikipedia.org/wiki/XML]()
 #'
 #' @keywords IO
 #'
@@ -508,8 +508,7 @@ read_XSYG2R <- function(
                 temp.sequence.object.curveValue.PMT <- src_get_XSYG_curve_values(XML::xmlValue(
                   temp[[x]][[i]][[j]]))
 
-
-                ##round values (1 digit is technical resolution of the heating element)
+                ##round values (1 digit is the technical resolution of the heating element)
                 temp.sequence.object.curveValue.PMT[,1] <- round(
                   temp.sequence.object.curveValue.PMT[,1], digits = 1)
 
@@ -518,7 +517,6 @@ read_XSYG2R <- function(
                   temp[[x]][[i]][[3]]))
 
 
-
               }else{
 
                 temp.sequence.object.curveValue.spectrum <- get_XSYG.spectrum.values(
@@ -547,7 +545,7 @@ read_XSYG2R <- function(
                     temp.sequence.object.curveValue.heating.element[,1] >=
                       min(temp.sequence.object.curveValue.PMT[,1]) &
                       temp.sequence.object.curveValue.heating.element[,1] <=
-                      max(temp.sequence.object.curveValue.PMT[,1]),]
+                      max(temp.sequence.object.curveValue.PMT[,1]), ,drop = FALSE]
 
               }else{
 
@@ -571,7 +569,7 @@ read_XSYG2R <- function(
               heating.rate.values <- temp.sequence.object.curveValue.heating.element[
                 temp.sequence.object.curveValue.heating.element[,2] > 0 &
                   temp.sequence.object.curveValue.heating.element[,2] <=
-                  max(temp.sequence.object.curveValue.heating.element[,2]),]
+                  max(temp.sequence.object.curveValue.heating.element[,2]),,drop = FALSE]
 
               heating.rate <- (heating.rate.values[length(heating.rate.values[,2]), 2] -
                                  heating.rate.values[1,2])/
@@ -657,7 +655,7 @@ read_XSYG2R <- function(
                     y = temp.sequence.object.curveValue.heating.element[,2],
                     xout = temp.sequence.object.curveValue.spectrum.time,
                     rule = 2,
-                    ties = -2)
+                    ties = mean)
 
                   temperature.values <-
                     temp.sequence.object.curveValue.heating.element.i$y
