@@ -1,5 +1,3 @@
-context("bin_RLum.Data")
-
 data(ExampleData.CW_OSL_Curve, envir = environment())
 curve <-
   set_RLum(
@@ -9,17 +7,18 @@ curve <-
   )
 
 
-
 test_that("check class and length of output", {
   testthat::skip_on_cran()
+  local_edition(3)
 
-  expect_is(bin_RLum.Data(curve), class = "RLum.Data.Curve", info = NULL, label = NULL)
+  expect_s4_class(bin_RLum.Data(curve), class = "RLum.Data.Curve")
   expect_length(bin_RLum.Data(curve)[,1], 500)
 
 })
 
 test_that("check values from output example", {
   testthat::skip_on_cran()
+  local_edition(3)
 
   expect_equal(sum(bin_RLum.Data(curve)[,2]), 119200)
   expect_equal(sum(bin_RLum.Data(curve, bin = 5)[1,2]), 41146)
